@@ -24,7 +24,8 @@
 /* The maximum number of threads (for some static arrays).
  * Choose this large enough for most monsters out there.
    Keep in sync this with the number in __init__.py. */
-#define MAX_THREADS 4096
+// #define MAX_THREADS 4096
+#define DEFAULT_MAX_THREADS 64
 
 #if defined(_WIN32)
   #include "win32/pthread.h"
